<?php
/**
 * Add Product Review Group Page
 *
 * @package ProductReviewPlugin
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

// Ensure WordPress editor scripts are loaded
wp_enqueue_editor();
add_filter('user_can_richedit', '__return_true');
remove_filter('the_content', 'wpautop');

$is_premium = ProductReviewPlugin::is_premium_user();
$max_reviews = $is_premium ? PHP_INT_MAX : 2;
?>

<div class="wrap">
    <h1><?php esc_html_e( 'Add New Product Review Group', 'product-review-shortcode' ); ?></h1>

    <form method="post" action="<?php echo esc_url( admin_url( 'admin-post.php' ) ); ?>" id="product-review-group-form">
        <input type="hidden" name="action" value="add_product_review_group">
        <?php wp_nonce_field( 'add_product_review_group_nonce' ); ?>

        <table class="form-table">
            <tr>
                <th scope="row"><label for="group_label"><?php esc_html_e( 'Group Label', 'product-review-shortcode' ); ?></label></th>
                <td><input name="group_label" type="text" id="group_label" class="regular-text" required></td>
            </tr>
        </table>

        <div id="review-forms-container">
            <div class="review-form" data-review-index="0">
                <h3><?php esc_html_e( 'Product Review #1', 'product-review-shortcode' ); ?></h3>
                <table class="form-table">
                    <tr>
                        <th scope="row"><label for="product_name_0"><?php esc_html_e( 'Product Name', 'product-review-shortcode' ); ?></label></th>
                        <td><input name="product_name[]" type="text" id="product_name_0" class="regular-text" required></td>
                    </tr>
                    <tr>
                        <th scope="row"><label for="product_category_0"><?php esc_html_e( 'Product Category', 'product-review-shortcode' ); ?></label></th>
                        <td><input name="product_category[]" type="text" id="product_category_0" class="regular-text" required></td>
                    </tr>
                    <tr>
                        <th scope="row"><label for="product_rating_0"><?php esc_html_e( 'Product Rating', 'product-review-shortcode' ); ?></label></th>
                        <td><input name="product_rating[]" type="number" id="product_rating_0" class="small-text" step="0.1" min="0" max="5" required></td>
                    </tr>
                    <tr>
                        <th scope="row"><label for="product_price_0"><?php esc_html_e( 'Product Price', 'product-review-shortcode' ); ?></label></th>
                        <td><input name="product_price[]" type="number" id="product_price_0" class="regular-text" step="0.01" required></td>
                    </tr>
                    <tr>
                        <th scope="row"><label for="product_summary_0"><?php esc_html_e( 'Product Summary', 'product-review-shortcode' ); ?></label></th>
                        <td><textarea name="product_summary[]" id="product_summary_0" rows="5" cols="50" required></textarea></td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="product_image_0">
                                <?php esc_html_e('Product Image', 'product-review-shortcode'); ?>
                            </label>
                        </th>
                        <td>
                            <div class="image-upload-container">
                                <input type="text" 
                                       name="product_image[]" 
                                       id="product_image_0" 
                                       class="regular-text">
                                <button type="button" class="button upload-image-button">
                                    <?php esc_html_e('Upload Image', 'product-review-shortcode'); ?>
                                </button>
                                <div class="media-preview"></div>
                            </div>
                        </td>
                    </tr>
                    <tr>
    <th scope="row"><label for="product_description_0"><?php esc_html_e('Description', 'product-review-shortcode'); ?></label></th>
    <td>
        <?php
        $editor_id = 'product_description_0';
        $content = '';
        $settings = array(
            'textarea_name' => 'product_description[]',
            'textarea_rows' => 10,
            'media_buttons' => true,
            'tinymce'      => array(
                'toolbar1'  => 'formatselect,bold,italic,bullist,numlist,blockquote,alignleft,aligncenter,alignright,link,unlink,wp_more,spellchecker,fullscreen,wp_adv',
                'toolbar2'  => 'strikethrough,hr,forecolor,pastetext,removeformat,charmap,outdent,indent,undo,redo,wp_help'
            ),
            'quicktags'    => true,
        );
        wp_editor($content, $editor_id, $settings);
        ?>
    </td>
</tr>

                    <tr>
                        <th scope="row"><label><?php esc_html_e( 'Features', 'product-review-shortcode' ); ?></label></th>
                        <td>
                            <table class="features-table">
                                <tr>
                                    <th><?php esc_html_e( 'Feature', 'product-review-shortcode' ); ?></th>
                                    <th><?php esc_html_e( 'Value', 'product-review-shortcode' ); ?></th>
                                    <th><?php esc_html_e( 'Action', 'product-review-shortcode' ); ?></th>
                                </tr>
                            </table>
                            <button type="button" class="add-feature button"><?php esc_html_e( 'Add Feature', 'product-review-shortcode' ); ?></button>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><label for="product_pros_0"><?php esc_html_e( 'Pros (one per line)', 'product-review-shortcode' ); ?></label></th>
                        <td><textarea name="product_pros[]" id="product_pros_0" rows="5" cols="50" required></textarea></td>
                    </tr>
                    <tr>
                        <th scope="row"><label for="product_cons_0"><?php esc_html_e( 'Cons (one per line)', 'product-review-shortcode' ); ?></label></th>
                        <td><textarea name="product_cons[]" id="product_cons_0" rows="5" cols="50" required></textarea></td>
                    </tr>
                    <tr>
                        <th scope="row"><label for="product_who_should_buy_0"><?php esc_html_e( 'Who Should Buy (one per line)', 'product-review-shortcode' ); ?></label></th>
                        <td><textarea name="product_who_should_buy[]" id="product_who_should_buy_0" rows="5" cols="50" required></textarea></td>
                    </tr>
                    <tr>
                        <th scope="row"><label for="button_text_0"><?php esc_html_e( 'Button Text', 'product-review-shortcode' ); ?></label></th>
                        <td><input type="text" name="button_text[]" id="button_text_0" value="<?php esc_attr_e( 'Add to Cart', 'product-review-shortcode' ); ?>"></td>
                    </tr>
                    <tr>
                        <th scope="row"><label for="button_url_0"><?php esc_html_e( 'Button URL', 'product-review-shortcode' ); ?></label></th>
                        <td><input type="text" name="button_url[]" id="button_url_0"></td>
                    </tr>
                </table>
                <button type="button" class="button duplicate-review-form"><?php esc_html_e( 'Duplicate This Review', 'product-review-shortcode' ); ?></button>
            </div>
        </div>

        <button type="button" id="add-review-form" class="button"><?php esc_html_e( 'Add Another Review', 'product-review-shortcode' ); ?></button>
        <?php if ( ! $is_premium ) : ?>
            <p class="description">
                <?php
                echo sprintf(
                    esc_html__( 'Free users can add up to %1$s product reviews per group. %2$sUpgrade to add more!%3$s', 'product-review-shortcode' ),
                    $max_reviews,
                    '<a href="https://teclans.info/store/product/product-review-plugin/">',
                    '</a>'
                );
                ?>
            </p>
        <?php endif; ?>

        <?php submit_button( esc_html__( 'Add Product Review Group', 'product-review-shortcode' ) ); ?>
    </form>
</div>

<script type="text/template" id="review-form-template">
<div class="review-form" data-review-index="{{index}}">
    <h3><?php esc_html_e( 'Product Review #{{reviewNumber}}', 'product-review-shortcode' ); ?></h3>
    <table class="form-table">
        <tr>
            <th scope="row"><label for="product_name_{{index}}"><?php esc_html_e( 'Product Name', 'product-review-shortcode' ); ?></label></th>
            <td><input name="product_name[]" type="text" id="product_name_{{index}}" class="regular-text" required></td>
        </tr>
        <tr>
            <th scope="row"><label for="product_category_{{index}}"><?php esc_html_e( 'Product Category', 'product-review-shortcode' ); ?></label></th>
            <td><input name="product_category[]" type="text" id="product_category_{{index}}" class="regular-text" required></td>
        </tr>
        <tr>
            <th scope="row"><label for="product_rating_{{index}}"><?php esc_html_e( 'Product Rating', 'product-review-shortcode' ); ?></label></th>
            <td><input name="product_rating[]" type="number" id="product_rating_{{index}}" class="small-text" step="0.1" min="0" max="5" required></td>
        </tr>
        <tr>
            <th scope="row"><label for="product_price_{{index}}"><?php esc_html_e( 'Product Price', 'product-review-shortcode' ); ?></label></th>
            <td><input name="product_price[]" type="number" id="product_price_{{index}}" class="regular-text" step="0.01" required></td>
        </tr>
        <tr>
            <th scope="row"><label for="product_summary_{{index}}"><?php esc_html_e( 'Product Summary', 'product-review-shortcode' ); ?></label></th>
            <td><textarea name="product_summary[]" id="product_summary_{{index}}" rows="5" cols="50" required></textarea></td>
        </tr>
        <tr>
        <th scope="row">
            <label for="product_image_{{index}}">
                <?php esc_html_e('Product Image', 'product-review-shortcode'); ?>
            </label>
        </th>
        <td>
            <div class="image-upload-container">
                <input type="text" 
                       name="product_image[]" 
                       id="product_image_{{index}}" 
                       class="regular-text">
                <button type="button" class="button upload-image-button">
                    <?php esc_html_e('Upload Image', 'product-review-shortcode'); ?>
                </button>
                <div class="media-preview"></div>
            </div>
        </td>
    </tr>
        <tr>
    <th scope="row"><label for="product_description_{{index}}"><?php esc_html_e('Description', 'product-review-shortcode'); ?></label></th>
    <td>
        <?php
        $settings = array(
            'textarea_name' => 'product_description[]',
            'textarea_rows' => 10,
            'media_buttons' => true,
            'tinymce'      => array(
                'toolbar1'  => 'formatselect,bold,italic,bullist,numlist,blockquote,alignleft,aligncenter,alignright,link,unlink,wp_more,spellchecker,fullscreen,wp_adv',
                'toolbar2'  => 'strikethrough,hr,forecolor,pastetext,removeformat,charmap,outdent,indent,undo,redo,wp_help'
            ),
            'quicktags'    => true,
        );
        // Use placeholder that will be replaced by JavaScript
        echo '<div class="editor-placeholder" data-editor-index="{{index}}"></div>';
        ?>
    </td>
</tr>
        <tr>
            <th scope="row"><label><?php esc_html_e( 'Features', 'product-review-shortcode' ); ?></label></th>
            <td>
                <table class="features-table">
                    <thead>
                        <tr>
                            <th><?php esc_html_e( 'Feature', 'product-review-shortcode' ); ?></th>
                            <th><?php esc_html_e( 'Value', 'product-review-shortcode' ); ?></th>
                            <th><?php esc_html_e( 'Action', 'product-review-shortcode' ); ?></th>
                        </tr>
                    </thead>
                    <tbody></tbody>
                </table>
                <button type="button" class="add-feature button"><?php esc_html_e( 'Add Feature', 'product-review-shortcode' ); ?></button>
            </td>
        </tr>
        <tr>
            <th scope="row"><label for="product_pros_{{index}}"><?php esc_html_e( 'Pros (one per line)', 'product-review-shortcode' ); ?></label></th>
            <td><textarea name="product_pros[]" id="product_pros_{{index}}" rows="5" cols="50" required></textarea></td>
        </tr>
        <tr>
            <th scope="row"><label for="product_cons_{{index}}"><?php esc_html_e( 'Cons (one per line)', 'product-review-shortcode' ); ?></label></th>
            <td><textarea name="product_cons[]" id="product_cons_{{index}}" rows="5" cols="50" required></textarea></td>
        </tr>
        <tr>
            <th scope="row"><label for="product_who_should_buy_{{index}}"><?php esc_html_e( 'Who Should Buy (one per line)', 'product-review-shortcode' ); ?></label></th>
            <td><textarea name="product_who_should_buy[]" id="product_who_should_buy_{{index}}" rows="5" cols="50" required></textarea></td>
        </tr>
        <tr>
            <th scope="row"><label for="button_text_{{index}}"><?php esc_html_e( 'Button Text', 'product-review-shortcode' ); ?></label></th>
            <td><input type="text" name="button_text[]" id="button_text_{{index}}" value="<?php esc_attr_e( 'Add to Cart', 'product-review-shortcode' ); ?>"></td>
        </tr>
        <tr>
            <th scope="row"><label for="button_url_{{index}}"><?php esc_html_e( 'Button URL', 'product-review-shortcode' ); ?></label></th>
            <td><input type="text" name="button_url[]" id="button_url_{{index}}"></td>
        </tr>
    </table>
</div>
</script>

<?php
wp_localize_script('product-review-admin-script', 'productReviewL10n', array(
    'maxReviewsMessage' => __('You have reached the maximum number of reviews allowed for free users. Please upgrade to add more.', 'product-review-shortcode'),
    'minReviewMessage' => __('You must have at least one review form.', 'product-review-shortcode'),
    'reviewNumberText' => __('Product Review #', 'product-review-shortcode'),
    'removeText' => __('Remove', 'product-review-shortcode'),
    'chooseImageText' => __('Choose Image', 'product-review-shortcode'),
    'useThisImageText' => __('Use this image', 'product-review-shortcode'),
    'removeImageText' => __('Remove image', 'product-review-shortcode'),
    'uploadImageText' => __('Upload Image', 'product-review-shortcode')
));
wp_enqueue_media();
wp_enqueue_script( 'product-review-admin-script', plugin_dir_url( __FILE__ ) . '../assets/js/admin-script.js', array( 'jquery' ), '1.0', true );
wp_localize_script( 'product-review-admin-script', 'productReviewSettings', array(
    'isPremiumUser' => $is_premium,
    'maxReviews' => $max_reviews,
    'ajaxurl' => admin_url( 'admin-ajax.php' ),
    'nonce' => wp_create_nonce( 'product_review_nonce' )
) );
?>