<?php
/**
 * License Page
 *
 * @package ProductReviewPlugin
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

$license_key = get_option( 'product_review_license_key', '' );
$license_status = get_option( 'product_review_license_status', 'inactive' );

if ( isset( $_POST['product_review_license_activate'] ) && check_admin_referer( 'product_review_license_nonce' ) ) {
    if ( ! empty( $_POST['product_review_license_key'] ) ) {
        $license_key = sanitize_text_field( wp_unslash( $_POST['product_review_license_key'] ) );
        $validation_result = ProductReviewPlugin::validate_license( $license_key );

        if ( $validation_result['is_valid'] ) {
            update_option( 'product_review_license_key', $license_key );
            update_option( 'product_review_license_status', 'active' );
            $license_status = 'active';
            add_settings_error( 'product_review_license', 'license_activated', __( 'License activated successfully.', 'product-review-shortcode' ), 'updated' );
        } else {
            $error_message = isset( $validation_result['error'] ) ? $validation_result['error'] : __( 'Unknown error occurred.', 'product-review-shortcode' );
            add_settings_error( 'product_review_license', 'license_activation_failed', sprintf( __( 'License activation failed: %s', 'product-review-shortcode' ), $error_message ), 'error' );
        }
    } else {
        add_settings_error( 'product_review_license', 'license_activation_failed', __( 'Please enter a valid license key.', 'product-review-shortcode' ), 'error' );
    }
}

if ( isset( $_POST['product_review_license_deactivate'] ) && check_admin_referer( 'product_review_license_nonce' ) ) {
    update_option( 'product_review_license_key', '' );
    update_option( 'product_review_license_status', 'inactive' );
    $license_status = 'inactive';
    $license_key = '';
    add_settings_error( 'product_review_license', 'license_deactivated', __( 'License deactivated successfully.', 'product-review-shortcode' ), 'updated' );
}
?>

<div class="wrap">
    <h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
    <?php settings_errors( 'product_review_license' ); ?>
    <form method="post" action="">
        <?php wp_nonce_field( 'product_review_license_nonce' ); ?>
        <table class="form-table">
            <tr valign="top">
                <th scope="row"><?php esc_html_e( 'License Key', 'product-review-shortcode' ); ?></th>
                <td>
                    <input type="text" name="product_review_license_key" value="<?php echo esc_attr( $license_key ); ?>" class="regular-text" <?php echo $license_status === 'active' ? 'disabled' : ''; ?> />
                    <?php if ( $license_status === 'inactive' ) : ?>
                        <input type="submit" name="product_review_license_activate" class="button-secondary" value="<?php esc_attr_e( 'Activate License', 'product-review-shortcode' ); ?>" />
                    <?php else : ?>
                        <input type="submit" name="product_review_license_deactivate" class="button-secondary" value="<?php esc_attr_e( 'Deactivate License', 'product-review-shortcode' ); ?>" />
                    <?php endif; ?>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row"><?php esc_html_e( 'License Status', 'product-review-shortcode' ); ?></th>
                <td>
                    <?php if ( $license_status === 'active' ): ?>
                        <span class="notice notice-success notice-alt inline">
                            <p><?php esc_html_e( 'Active', 'product-review-shortcode' ); ?></p>
                        </span>
                    <?php else: ?>
                        <span class="notice notice-warning notice-alt inline">
                            <p><?php esc_html_e( 'Inactive', 'product-review-shortcode' ); ?></p>
                        </span>
                    <?php endif; ?>
                </td>
            </tr>
        </table>
    </form>

    <?php if ($license_status === 'active'): ?>
    <div class="notice notice-info">
        <p>
            <?php esc_html_e('Your license is currently active. You have access to all premium features.', 'product-review-shortcode'); ?>
        </p>
    </div>
    <?php else: ?>
    <div class="notice notice-info">
        <p>
            <?php 
            echo sprintf(
                /* translators: %s: plugin store URL */
                esc_html__('To access premium features, please purchase a license from our %sstore%s.', 'product-review-shortcode'),
                '<a href="https://teclans.info/store/product/product-review-plugin/" target="_blank">',
                '</a>'
            ); 
            ?>
        </p>
        <p>
            <?php esc_html_e('Premium features include:', 'product-review-shortcode'); ?>
        </p>
        <ul class="ul-disc">
            <li><?php esc_html_e('Unlimited product reviews per group', 'product-review-shortcode'); ?></li>
            <li><?php esc_html_e('Priority email support', 'product-review-shortcode'); ?></li>
            <li><?php esc_html_e('Regular updates with new features', 'product-review-shortcode'); ?></li>
        </ul>
    </div>
    <?php endif; ?>
</div>